//
// MDL-style Button component.
//
// - @see [MDL Button](http://www.getmdl.io/components/index.html#buttons-section)
// - [Props](#props)
// - [Defaults](#defaults)
//
// Created by ywu on 15/7/2.
//

const React = require('react-native');
const MKColor = require('../MKColor');
const utils = require('../utils');

const {
  Component,
  Animated,
  View,
  TouchableWithoutFeedback,
} = React;

//
// ## <section id='Button'>Button</section>
// The `Button` component. With configurable shadow, ripple effect, and FAB style.
//
class Button extends Component {
  _onPressIn() {
    // TODO start ripple
    if (this.props.onPressIn) {
      this.props.onPressIn();
    }
  }

  _onPressOut() {
    // TODO end ripple
    if (this.props.onPressOut) {
      this.props.onPressOut();
    }
  }

  render() {
    const touchableProps = {};
    if (this.props.enabled) {
      Object.assign(touchableProps, utils.getTouchableProps(this));
    }

    return (
      <TouchableWithoutFeedback {...touchableProps}
        onPressIn={this._onPressIn.bind(this)}
        onPressOut={this._onPressOut.bind(this)}
        >
      </TouchableWithoutFeedback>
    );
  }
}

// ## <section id='props'>Props</section>
// ## <section id='defaults'>Defaults</section>
Button.defaultProps = {
  enabled: true,
  rippleEnabled: true,
  style: {
    backgroundColor: MKColor.Indigo,
    shadowColor: 'black',
    shadowRadius: 2,
    shadowOpacity: 0.7,
    shadowOffset: {width: 0, height: 2},
  },
};


// ## Public interface
module.exports = Button;
